@@ -122,6 +122,10 @@ def sort(t: TensorType, axis: int = -1) -> TensorType:
     return t.sort(axis=axis)
 
 
+def topk(t: TensorType, k: int, sorted: bool = True) -> Tuple[TensorType, TensorType]:
+    return t.topk(k, sorted=sorted)
+
+
 def uniform(
     t: TensorType, shape: ShapeOrScalar, low: float = 0.0, high: float = 1.0
 ) -> TensorType:
@@ -321,6 +325,10 @@ def crossentropy(logits: TensorType, labels: TensorType) -> TensorType:
     return logits.crossentropy(labels)
 
 
+def slogdet(matrix: TensorType) -> Tuple[TensorType, TensorType]:
+    return matrix.slogdet()
+
+
 @overload
 def value_and_grad_fn(
     t: TensorType, f: Callable[..., TensorType]
