@@ -1,4 +1,8 @@
-from .base import AbstractBaseTensor as Tensor  # noqa: F401
+from .tensor import Tensor  # noqa: F401
+from .tensor import TensorType  # noqa: F401
+from .tensor import TensorOrScalar  # noqa: F401
+from .tensor import istensor  # noqa: F401
+
 from .pytorch import PyTorchTensor  # noqa: F401
 from .tensorflow import TensorFlowTensor  # noqa: F401
 from .numpy import NumPyTensor  # noqa: F401
