@@ -203,6 +203,12 @@ class PyTorchTensor(BaseTensor):
     def sort(self: TensorType, axis: int = -1) -> TensorType:
         return type(self)(self.raw.sort(dim=axis).values)  # type: ignore
 
+    def topk(
+        self: TensorType, k: int, sorted: bool = True
+    ) -> Tuple[TensorType, TensorType]:
+        values, indices = self.raw.topk(k, sorted=sorted)
+        return type(self)(values), type(self)(indices)
+
     def uniform(
         self: TensorType, shape: ShapeOrScalar, low: float = 0.0, high: float = 1.0
     ) -> TensorType:
@@ -464,6 +470,10 @@ class PyTorchTensor(BaseTensor):
             torch.nn.functional.cross_entropy(self.raw, labels.raw, reduction="none")
         )
 
+    def slogdet(self: TensorType) -> Tuple[TensorType, TensorType]:
+        sign, logabsdet = torch.slogdet(self.raw)
+        return type(self)(sign), type(self)(logabsdet)
+
     @overload
     def _value_and_grad_fn(
         self: TensorType, f: Callable[..., TensorType]
@@ -525,11 +535,19 @@ class PyTorchTensor(BaseTensor):
     def float32(self: TensorType) -> TensorType:
         return self.astype(torch.float32)
 
+    def float64(self: TensorType) -> TensorType:
+        return self.astype(torch.float64)
+
     def where(self: TensorType, x: TensorOrScalar, y: TensorOrScalar) -> TensorType:
+
         if isinstance(x, Tensor):
             x_ = x.raw
         elif isinstance(x, int) or isinstance(x, float):
-            x_ = torch.full_like(self.raw, x, dtype=torch.float32)
+            if isinstance(y, Tensor):
+                dtype = y.raw.dtype
+            else:
+                dtype = torch.float32
+            x_ = torch.full_like(self.raw, x, dtype=dtype)
         else:
             raise TypeError(
                 "expected x to be a Tensor, int or float"
@@ -537,16 +555,13 @@ class PyTorchTensor(BaseTensor):
         if isinstance(y, Tensor):
             y_ = y.raw
         elif isinstance(y, int) or isinstance(y, float):
-            y_ = torch.full_like(self.raw, y, dtype=torch.float32)
+            if isinstance(x, Tensor):
+                dtype = x.raw.dtype
+            else:
+                dtype = torch.float32
+            y_ = torch.full_like(self.raw, y, dtype=dtype)
         return type(self)(torch.where(self.raw, x_, y_))
 
-    def matmul(self: TensorType, other: TensorType) -> TensorType:
-        if self.ndim != 2 or other.ndim != 2:
-            raise ValueError(
-                f"matmul requires both tensors to be 2D, got {self.ndim}D and {other.ndim}D"
-            )
-        return type(self)(torch.matmul(self.raw, other.raw))
-
     def __lt__(self: TensorType, other: TensorOrScalar) -> TensorType:
         return type(self)(self.raw.__lt__(unwrap1(other)))
 
