@@ -176,6 +176,12 @@ class TensorFlowTensor(BaseTensor):
     def sort(self: TensorType, axis: Optional[int] = -1) -> TensorType:
         return type(self)(tf.sort(self.raw, axis=axis))
 
+    def topk(
+        self: TensorType, k: int, sorted: bool = True
+    ) -> Tuple[TensorType, TensorType]:
+        values, indices = tf.math.top_k(self.raw, k, sorted=sorted)
+        return type(self)(values), type(self)(indices)
+
     @samedevice
     def uniform(
         self: TensorType, shape: ShapeOrScalar, low: float = 0.0, high: float = 1.0
@@ -436,6 +442,10 @@ class TensorFlowTensor(BaseTensor):
             tf.nn.sparse_softmax_cross_entropy_with_logits(labels.raw, self.raw)
         )
 
+    def slogdet(self: TensorType) -> Tuple[TensorType, TensorType]:
+        sign, logabsdet = tf.linalg.slogdet(self.raw)
+        return type(self)(sign), type(self)(logabsdet)
+
     @overload
     def _value_and_grad_fn(
         self: TensorType, f: Callable[..., TensorType]
@@ -491,17 +501,13 @@ class TensorFlowTensor(BaseTensor):
     def float32(self: TensorType) -> TensorType:
         return self.astype(tf.float32)
 
+    def float64(self: TensorType) -> TensorType:
+        return self.astype(tf.float64)
+
     def where(self: TensorType, x: TensorOrScalar, y: TensorOrScalar) -> TensorType:
         x, y = unwrap_(x, y)
         return type(self)(tf.where(self.raw, x, y))
 
-    def matmul(self: TensorType, other: TensorType) -> TensorType:
-        if self.ndim != 2 or other.ndim != 2:
-            raise ValueError(
-                f"matmul requires both tensors to be 2D, got {self.ndim}D and {other.ndim}D"
-            )
-        return type(self)(tf.matmul(self.raw, other.raw))
-
     @common_dtype
     def __lt__(self: TensorType, other: TensorOrScalar) -> TensorType:
         return type(self)(self.raw.__lt__(unwrap1(other)))
