@@ -1,6 +1,7 @@
 from typing import Callable, Dict, Any, Tuple, Union, Optional, cast
 import pytest
 import functools
+import itertools
 import numpy as np
 import eagerpy as ep
 from eagerpy import Tensor
@@ -1206,6 +1207,20 @@ def test_sort(dummy: Tensor) -> Tensor:
     return ep.sort(t)
 
 
+@compare_all
+def test_topk_values(dummy: Tensor) -> Tensor:
+    t = (ep.arange(dummy, 27).reshape((3, 3, 3)) ** 2 * 10000 % 1234).float32()
+    values, _ = ep.topk(t, 2)
+    return values
+
+
+@compare_all
+def test_topk_indices(dummy: Tensor) -> Tensor:
+    t = -(ep.arange(dummy, 27).reshape((3, 3, 3)) ** 2 * 10000 % 1234).float32()
+    _, indices = ep.topk(t, 2)
+    return indices
+
+
 @compare_all
 def test_transpose(dummy: Tensor) -> Tensor:
     t = ep.arange(dummy, 8).float32().reshape((2, 4))
@@ -1233,6 +1248,18 @@ def test_where_second_scalar(t: Tensor) -> Tensor:
     return ep.where(t >= 3, t, 2)
 
 
+@compare_all
+def test_where_first_scalar64(dummy: Tensor) -> Tensor:
+    t = ep.arange(dummy, 60).float64().reshape((3, 4, 5))
+    return ep.where(t >= 3, 2, -t)
+
+
+@compare_all
+def test_where_second_scalar64(dummy: Tensor) -> Tensor:
+    t = ep.arange(dummy, 60).float64().reshape((3, 4, 5))
+    return ep.where(t >= 3, t, 2)
+
+
 @compare_all
 def test_where_both_scalars(t: Tensor) -> Tensor:
     return ep.where(t >= 3, 2, 5)
@@ -1249,6 +1276,12 @@ def test_matmul(dummy: Tensor) -> Tensor:
     return ep.matmul(t, t.T)
 
 
+@compare_all
+def test_matmul_operator(dummy: Tensor) -> Tensor:
+    t = ep.arange(dummy, 8).float32().reshape((2, 4))
+    return t @ t.T
+
+
 @compare_allclose(rtol=1e-6)
 def test_softmax(t: Tensor) -> Tensor:
     return ep.softmax(t)
@@ -1266,6 +1299,32 @@ def test_crossentropy(dummy: Tensor) -> Tensor:
     return ep.crossentropy(t, t.argmax(axis=-1))
 
 
+@pytest.mark.parametrize(
+    "array, output",
+    itertools.product(
+        [
+            np.array([[1, 2], [3, 4]]),
+            np.array([[[1, 2], [3, 4]], [[1, 2], [2, 1]], [[1, 3], [3, 1]]]),
+            np.arange(100).reshape((10, 10)),
+        ],
+        ["sign", "logdet"],
+    ),
+    ids=map(
+        lambda *l: "_".join(*l),
+        itertools.product(
+            ["matrix_finite", "stack_of_matrices", "matrix_infinite"],
+            ["sign", "logdet"],
+        ),
+    ),
+)
+@compare_allclose
+def test_slogdet(dummy: Tensor, array: Tensor, output: str) -> Tensor:
+    a = ep.from_numpy(dummy, array).float32()
+    outputs = dict()
+    outputs["sign"], outputs["logdet"] = ep.slogdet(a)
+    return outputs[output]
+
+
 @pytest.mark.parametrize("axis", [0, 1, -1])
 @compare_all
 def test_stack(t1: Tensor, t2: Tensor, axis: int) -> Tensor:
